@@ -393,7 +393,8 @@ class CogniacConnection(object):
                      domain_unit=None,
                      trigger_id=None,
                      sequence_ix=None,
-                     custom_data=None):
+                     custom_data=None,
+                     fp=None):
         """
         Create a new CogniacMedia object and upload the media to the Cogniac System.
 
@@ -412,9 +413,11 @@ class CogniacConnection(object):
                                           Media with the same domain_unit will always be assigned to the same
                                           training or validation set. Set this to avoid overfitting when you have
                                           multiple images of the same thing or almost the same thing.
-        trigger_id (str):                 unique trigger identifier leading to a media sequence containing this media
-        sequence_ix (str):                the index of this media within a triggered sequence
-        custom_data (str):                opaque user-specified data associated with this media; limited to 32KB
+        trigger_id (str):                 Unique trigger identifier leading to a media sequence containing this media
+        sequence_ix (str):                The index of this media within a triggered sequence
+        custom_data (str):                Opaque user-specified data associated with this media; limited to 32KB
+        fp (file):                        A '.read()'-supporting file-like object (under 16MB) from which to acquire
+                                          the media instead of reading the media from the specified filename.
         """
         return CogniacMedia.create(self,
                                    filename=filename,
@@ -431,7 +434,8 @@ class CogniacConnection(object):
                                    domain_unit=domain_unit,
                                    trigger_id=trigger_id,
                                    sequence_ix=sequence_ix,
-                                   custom_data=custom_data)
+                                   custom_data=custom_data,
+                                   fp=fp)
 
     def get_version(self, auth=False):
         """
